=======
History
=======

0.1.3 (2024-02-25)
------------------

* ci: Add automated testing workflow for pull requests by @CodeWithEmad in https://github.com/CodeWithEmad/apyrat/pull/1
* fix: no prompt with confirmation by @CodeWithEmad in https://github.com/CodeWithEmad/apyrat/pull/5

0.1.2 (2023-08-12)
------------------

* First release on PyPI.
